==> bitmio-0.0.3.tar.gz: lib/card_detail.dart <==
import 'package:flutter/material.dart';

import 'blurred_image.dart';

class CardModel {
  String title;
  String date;
  PersonModel person;
  String description;
  Image background;

  CardModel(
      {this.title, this.date, this.person, this.description, this.background});
}

class PersonModel {
  String name;
  ImageProvider image;

  PersonModel({this.name, this.image});
}

class CardDetailWidget extends StatelessWidget {
  CardModel model;
  Function showAssignee;
  List<Widget> widgets;

  CardDetailWidget({this.model, this.widgets});

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      //extendBody: true,
      extendBodyBehindAppBar: true,
      //backgroundColor: Colors.transparent,
      appBar: new AppBar(
        //automaticallyImplyLeading: false,
        backgroundColor: Colors.transparent,
        elevation: 0,
      ),
      body: SingleChildScrollView(
        child: Column(children: <Widget>[
          Stack(
            children: <Widget>[
              Container(
                  height: model.background != null ? 300 : 250,
                  color: Theme.of(context).primaryColor,
                  width: double.infinity,
                  child: model.background != null
                      ? BlurredImage(model.background)
                      : null),
              Positioned(
                  bottom: 20,
                  left: 0,
                  right: 0,
                  child: Container(
                      padding:
                          EdgeInsets.symmetric(vertical: 12, horizontal: 12),
                      decoration:
                          BoxDecoration(color: Colors.black.withOpacity(0.4)),
                      child: Column(
                        crossAxisAlignment: CrossAxisAlignment.start,
                        children: <Widget>[
                          Text(model.title,
                              style: Theme.of(context)
                                  .textTheme
                                  .title
                                  .copyWith(color: Colors.white)),
                          SizedBox(height: 20),
                          Wrap(
                            spacing: 20,
                            crossAxisAlignment: WrapCrossAlignment.center,
                            children: <Widget>[
                              if (model.date != null)
                                Wrap(
                                    spacing: 5,
                                    crossAxisAlignment:
                                        WrapCrossAlignment.center,
                                    children: <Widget>[
                                      Icon(Icons.calendar_today,
                                          color: Colors.white),
                                      Text(model.date,
                                          style: TextStyle(color: Colors.white))
                                    ]),
                              if (model.person != null)
                                InkWell(
                                    onTap: () => showAssignee(),
                                    child: Wrap(
                                      crossAxisAlignment:
                                          WrapCrossAlignment.center,
                                      spacing: 5,
                                      children: <Widget>[
                                        Container(
                                            width: 30,
                                            height: 30,
                                            child: AspectRatio(
                                              child: CircleAvatar(
                                                  backgroundImage:
                                                      model.person.image),
                                              aspectRatio: 1,
                                            )),
                                        Text(model.person.name,
                                            style:
                                                TextStyle(color: Colors.white)),
                                      ],
                                    ))
                            ],
                          )
                        ],
                      )))
            ],
          ),
          Container(
            padding: EdgeInsets.symmetric(vertical: 24, horizontal: 12),
            width: double.infinity,
            child: Text(model.description),
          ),
          if (widgets != null) Column(children: widgets)
        ]),
      ),
    );
  }
}

==> bitmio-0.0.4.tar.gz: lib/card_detail.dart <==
import 'package:flutter/material.dart';

import 'blurred_image.dart';

class CardModel {
  String title;
  String date;
  PersonModel person;
  String description;
  Image background;

  CardModel(
      {this.title, this.date, this.person, this.description, this.background});
}

class PersonModel {
  String name;
  ImageProvider image;

  PersonModel({this.name, this.image});
}

class CardDetailWidget extends StatelessWidget {
  CardModel model;
  Function showAssignee;
  List<Widget> widgets;

  CardDetailWidget({this.model, this.widgets, this.showAssignee});

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      //extendBody: true,
      extendBodyBehindAppBar: true,
      //backgroundColor: Colors.transparent,
      appBar: new AppBar(
        //automaticallyImplyLeading: false,
        backgroundColor: Colors.transparent,
        elevation: 0.1,
      ),
      body: SingleChildScrollView(
        child: Column(children: <Widget>[
          Stack(
            children: <Widget>[
              Container(
                  height: model.background != null ? 300 : 250,
                  color: Theme.of(context).primaryColor,
                  width: double.infinity,
                  child: model.background != null
                      ? BlurredImage(model.background)
                      : null),
              Positioned(
                  bottom: 20,
                  left: 0,
                  right: 0,
                  child: Container(
                      padding:
                          EdgeInsets.symmetric(vertical: 12, horizontal: 12),
                      decoration:
                          BoxDecoration(color: Colors.black.withOpacity(0.4)),
                      child: Column(
                        crossAxisAlignment: CrossAxisAlignment.start,
                        children: <Widget>[
                          Text(model.title,
                              style: Theme.of(context)
                                  .textTheme
                                  .title
                                  .copyWith(color: Colors.white)),
                          SizedBox(height: 20),
                          Wrap(
                            spacing: 20,
                            crossAxisAlignment: WrapCrossAlignment.center,
                            children: <Widget>[
                              if (model.date != null)
                                Wrap(
                                    spacing: 5,
                                    crossAxisAlignment:
                                        WrapCrossAlignment.center,
                                    children: <Widget>[
                                      Icon(Icons.calendar_today,
                                          color: Colors.white),
                                      Text(model.date,
                                          style: TextStyle(color: Colors.white))
                                    ]),
                              if (model.person != null)
                                InkWell(
                                    onTap: () { if (showAssignee != null) showAssignee(); },
                                    child: Wrap(
                                      crossAxisAlignment:
                                          WrapCrossAlignment.center,
                                      spacing: 5,
                                      children: <Widget>[
                                        Container(
                                            width: 30,
                                            height: 30,
                                            child: AspectRatio(
                                              child: CircleAvatar(
                                                  backgroundImage:
                                                      model.person.image),
                                              aspectRatio: 1,
                                            )),
                                        Text(model.person.name,
                                            style:
                                                TextStyle(color: Colors.white)),
                                      ],
                                    ))
                            ],
                          )
                        ],
                      )))
            ],
          ),
          Container(
            padding: EdgeInsets.symmetric(vertical: 24, horizontal: 12),
            width: double.infinity,
            child: Text(model.description),
          ),
          if (widgets != null) Column(children: widgets)
        ]),
      ),
    );
  }
}
